@@ -5,9 +5,9 @@ use warnings;
 
 use base qw(Config::INI::Reader);
 
-our $VERSION = '0.70';
+our $VERSION = '0.71';
 
-my %multi_value = map { $_ => 1 } qw( ignore inc select shebang );
+my %multi_value = map { $_ => 1 } qw( ignore inc ok_exit_codes select shebang );
 
 sub set_value {
     my ( $self, $name, $value ) = @_;
@@ -41,7 +41,7 @@ can handle a key appearing more than once
 
 =head1 VERSION
 
-version 0.70
+version 0.71
 
 =head1 SUPPORT
 
